<?php
/**
 * Accessibility Settings Option for Live Popup Sales Notification.
 *
 * @since      1.0.0
 *
 * @package    Live_Popup_Sales_Notification_Settings_Options
 * @subpackage Live_Popup_Sales_Notification_Settings_Options/admin
 */

/**
 * Accessibility Settings Option for Live Popup Sales Notification.
 *
 * Handles the settings related to accessibility in the Live Popup Sales Notification.
 *
 * @package    Live_Popup_Sales_Notification_Settings_Options
 * @subpackage Live_Popup_Sales_Notification_Settings_Options/admin
 */
class Live_Popup_Sales_Notification_Settings_Options {

	/**
	 * The ID of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $plugin_name    The ID of this plugin.
	 */
	private $plugin_name;

	/**
	 * The version of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $version    The current version of this plugin.
	 */
	private $version;

	/**
	 * Settings api.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $settings_api    The options of this plugin.
	 */
	private $settings_api;

	/**
	 * Initialize the class and set its properties.
	 *
	 * @since    1.0.0
	 * @param      string $plugin_name      The name of this plugin.
	 * @param      string $version          The version of this plugin.
	 * @param      object $settings_manager The settings manager of this plugin.
	 */
	public function __construct( $plugin_name, $version, $settings_manager ) {

		$this->plugin_name  = $plugin_name;
		$this->version      = $version;
		$this->settings_api = $settings_manager;
	}

	/**
	 * Enqueue admin-specific stylesheets for the plugin settings page.
	 *
	 * @param string $hook The current admin page hook.
	 */
	public function enqueue_styles( $hook ) {

		// Check if the current admin page is the settings page for 'lpsn-settings'.
		if ( 'toplevel_page_lpsn-settings' === $hook ) {

			// Enqueue the admin-specific stylesheet for the plugin settings page.
			wp_enqueue_style(
				$this->plugin_name . '-admin',
				LIVE_POPUP_SALES_NOTIFICATION_PLUGINS_URL . 'assets/css/lpsn-admin-menu.min.css',
				array(),
				$this->version,
				'all'
			);
		}
	}

	/**
	 * Returns the URL of the custom SVG icon for the menu.
	 *
	 * @return string The URL to the SVG icon.
	 */
	public function get_custom_svg_icon() {
		// Assuming the SVG icon is saved in your plugin's 'assets' directory.
		return LIVE_POPUP_SALES_NOTIFICATION_PLUGINS_URL . 'assets/images/icon.svg';
	}

	/**
	 * Registers the top-level admin menu page and adds a submenu page for 'Live Popup Sales Notification'.
	 *
	 * This function uses the WordPress add_menu_page() and add_submenu_page() functions to create
	 * the necessary admin menu structure. It also sets up the callback functions for
	 * the top-level and submenu pages.
	 *
	 * @return void
	 */
	public function register_admin_menu_page() {
		add_menu_page(
			__( 'Notification', 'live-popup-sales-notification' ), // Page title.
			__( 'Notification', 'live-popup-sales-notification' ), // Menu title.
			'manage_options', // Capability required.
			'lpsn-settings', // Menu slug.
			array( $this, 'callback_template_for_settings' ), // Callback function.
			'dashicons-bell',  // URL icon SVG.
			30 // $position.
		);
		add_submenu_page(
			'lpsn-settings', // Parent menu slug.
			__( 'Settings', 'live-popup-sales-notification' ), // Page title.
			__( 'Settings', 'live-popup-sales-notification' ), // Menu title.
			'manage_options', // Capability required.
			'lpsn-settings', // Menu slug.
			array( $this, 'callback_template_for_settings' ) // Callback function.
		);
	}

	/**
	 * Loads the template for the 'Settings' menu page in the plugin.
	 *
	 * This function constructs the path to the template file located
	 * in the plugin directory and includes it if it exists.
	 */
	public function callback_template_for_settings() {
		// Define the path to the template file.
		$template_path = plugin_dir_path( __FILE__ ) . 'partials/settings.php';

		// Check if the template file exists.
		if ( file_exists( $template_path ) ) {
			// Include the template file if it exists.
			include $template_path;
		}
	}

	/**
	 * Remove notifications.
	 */
	public function hide_notifications_for_sales_notification_page() {
		if ( is_admin() && get_admin_page_parent() === 'lpsn-settings' ) {
			remove_all_actions( 'admin_notices' );
		}
	}

	/**
	 * Initialize the admin settings.
	 *
	 * This method sets the sections and fields for the settings API and initializes them.
	 *
	 * @return void
	 */
	public function admin_init() {

		// Set the settings api.
		$this->settings_api->set_sections( $this->get_settings_api_sections() );
		$this->settings_api->set_fields( $this->get_settings_api_fields() );

		// Initialize settings api.
		$this->settings_api->admin_init();
	}

	/**
	 * Retrieve the settings sections for the plugin.
	 *
	 * This method returns an array of sections used in the settings API.
	 * Each section contains an ID and a title.
	 *
	 * @return array The array of settings sections.
	 */
	public function get_settings_api_sections() {
		$sections = array(
			array(
				'id'    => 'lpsn_general_settings',
				'title' => __( 'General Settings', 'live-popup-sales-notification' ),
			),
		);
		return $sections;
	}

	/**
	 * Returns all the settings fields
	 *
	 * @return array settings fields
	 */
	public function get_settings_api_fields() {
		$settings_fields = array(
			'lpsn_general_settings' => array(
				array(
					'name'              => 'enable_sales_notification_on_desktop',
					'title'             => __( 'Enable Sales Notification', 'live-popup-sales-notification' ),
					'label'             => __( 'Enable or disable notifications on desktop devices.', 'live-popup-sales-notification' ),
					'type'              => 'checkbox',
					'default'           => Live_Popup_Sales_Notification_Config::get_general( 'enable_sales_notification_on_desktop' ),
					'sanitize_callback' => 'sanitize_text_field',
				),
				array(
					'name'              => 'enable_sales_notification_on_tablet',
					'title'             => null,
					'label'             => __( 'Enable or disable notifications on tablet devices.', 'live-popup-sales-notification' ),
					'type'              => 'checkbox',
					'default'           => Live_Popup_Sales_Notification_Config::get_general( 'enable_sales_notification_on_tablet' ),
					'sanitize_callback' => 'sanitize_text_field',
				),
				array(
					'name'              => 'enable_sales_notification_on_mobile',
					'title'             => null,
					'label'             => __( 'Enable or disable notifications on mobile devices.', 'live-popup-sales-notification' ),
					'type'              => 'checkbox',
					'default'           => Live_Popup_Sales_Notification_Config::get_general( 'enable_sales_notification_on_mobile' ),
					'sanitize_callback' => 'sanitize_text_field',
				),
			),
		);

		return $settings_fields;
	}

	/**
	 * Get all the pages
	 *
	 * @return array page names with key value pairs
	 */
	public function get_pages() {
		$pages         = get_pages();
		$pages_options = array();
		if ( $pages ) {
			foreach ( $pages as $page ) {
				$pages_options[ $page->ID ] = $page->post_title;
			}
		}

		return $pages_options;
	}
}
