<?php
/**
 * The public-facing functionality of the plugin.
 *
 * @link       https://yukyhendiawan.com
 * @since      1.0.0
 *
 * @package    Live_Popup_Sales_Notification
 * @subpackage Live_Popup_Sales_Notification/public
 */

/**
 * The public-facing functionality of the plugin.
 *
 * Defines the plugin name, version, and two examples hooks for how to
 * enqueue the public-facing stylesheet and JavaScript.
 *
 * @package    Live_Popup_Sales_Notification
 * @subpackage Live_Popup_Sales_Notification/public
 * @author     Yuky Hendiawan <yukyhendiawan1998@gmail.com>
 */
class Live_Popup_Sales_Notification_Public {

	/**
	 * The ID of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $plugin_name    The ID of this plugin.
	 */
	private $plugin_name;

	/**
	 * The version of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $version    The current version of this plugin.
	 */
	private $version;

	/**
	 * Initialize the class and set its properties.
	 *
	 * @since    1.0.0
	 * @param      string $plugin_name       The name of the plugin.
	 * @param      string $version    The version of this plugin.
	 */
	public function __construct( $plugin_name, $version ) {

		$this->plugin_name = $plugin_name;
		$this->version     = $version;
	}

	/**
	 * Register the stylesheets for the public-facing side of the site.
	 *
	 * @since    1.0.0
	 */
	public function enqueue_styles() {

		wp_enqueue_style( $this->plugin_name, LIVE_POPUP_SALES_NOTIFICATION_PLUGINS_URL . 'assets/css/lpsn-public-style.min.css', array(), $this->version, 'all' );
	}

	/**
	 * Register the JavaScript for the public-facing side of the site.
	 *
	 * @since    1.0.0
	 */
	public function enqueue_scripts() {

		// Initialize an array to store order data.
		$completed_orders_data = array();
		if ( class_exists( 'WooCommerce' ) ) {

			/**
			 * Formats a date interval into a human-readable format.
			 *
			 * This function takes a DateInterval object and returns a string representing the time interval in a human-readable format.
			 *
			 * @param DateInterval $interval The DateInterval object representing the time interval.
			 *
			 * @return string The formatted time interval.
			 */
			function format_time_ago( $interval ) {
				if ( $interval->d > 0 ) {
					return $interval->d . ' day' . ( $interval->d > 1 ? 's' : '' ) . ' ago'; // More than 1 day.
				} elseif ( $interval->h > 0 ) {
					return $interval->h . ' hour' . ( $interval->h > 1 ? 's' : '' ) . ' ago'; // More than 1 hour.
				} elseif ( $interval->i > 0 ) {
					return $interval->i . ' minute' . ( $interval->i > 1 ? 's' : '' ) . ' ago'; // More than 1 minute.
				} else {
					return 'Just now'; // Less than a minute ago.
				}
			}

			// Set up the arguments for the query.
			$args = array(
				'limit'  => 20,                  // Get 20 orders.
				'status' => 'completed',         // Only get orders with 'completed' status.
				'return' => 'ids',               // Return only order IDs for efficiency.
			);

			// Get the orders.
			$orders = wc_get_orders( $args );

			// Loop through each order and get relevant details.
			foreach ( $orders as $order_id ) {
				$order = wc_get_order( $order_id );

				// Get the order creation date.
				$order_date   = $order->get_date_created();
				$current_time = new DateTime(); // Current time.
				$order_time   = new DateTime( $order_date->date( 'Y-m-d H:i:s' ) ); // Convert order creation date to DateTime.

				// Calculate the time difference.
				$interval = $current_time->diff( $order_time );

				// Initialize the completed orders data array.
				$completed_orders_data[] = array(
					'orderId'          => $order_id,
					'orderDate'        => $order->get_date_created()->date( 'Y-m-d H:i:s' ),
					'total'            => $order->get_total(),
					'billingFirstName' => $order->get_billing_first_name(),
					'billingLastName'  => $order->get_billing_last_name(),
					'billingEmail'     => $order->get_billing_email(),
					'billingAddress'   => $order->get_billing_address_1(),
					'billingCity'      => $order->get_billing_city(),
					'billingPostcode'  => $order->get_billing_postcode(),
					'billingCountry'   => $order->get_billing_country(),
					'billingPhone'     => $order->get_billing_phone(),
					'paymentMethod'    => $order->get_payment_method(),
					'status'           => $order->get_status(),
					'shippingTotal'    => $order->get_shipping_total(),
					'discountTotal'    => $order->get_discount_total(),
					'timeAgo'          => format_time_ago( $interval ),
					'products'         => array_values(
						array_map(
							function ( $item ) {
								$product = $item->get_product();
								return array(
									'name'  => $product->get_name(),
									'image' => wp_get_attachment_url( $product->get_image_id() ),
								);
							},
							$order->get_items()
						)
					),
				);
			}

			// Enqueue the JavaScript file for the live popup order notification.
			wp_enqueue_script(
				$this->plugin_name,
				LIVE_POPUP_SALES_NOTIFICATION_PLUGINS_URL . 'assets/js/script.min.js',
				array( 'jquery' ),
				$this->version,
				true
			);

			// Localize the script to make PHP variables accessible in JavaScript.
			wp_localize_script(
				$this->plugin_name,
				'lpsnData',
				array(
					'ajaxUrl' => admin_url( 'admin-ajax.php' ),
					'nonce'   => wp_create_nonce( 'ajax-nonce' ),
					'orders'  => $completed_orders_data,
				)
			);

		}
	}

	/**
	 * Displays the live popup sales notification template.
	 *
	 * This function retrieves the path to the template file for the live popup sales notification,
	 * checks if the file exists, and includes it if it does.
	 *
	 * @since 1.0.0
	 *
	 * @return void
	 */
	public function template_live_popup_sales_notification() {
		// Define the path to the template file.
		$template_path = LIVE_POPUP_SALES_NOTIFICATION_DIR_PATH . 'public/partials/template-live-popup-sales-notification.php';

		// Check if the template file exists.
		if ( file_exists( $template_path ) ) {
			// Include the template file if it exists.
			include $template_path;
		}
	}
}
